<?php

/**
 * @file
 * Contains \Drupal\field_slide_show_j360\Plugin\field\formatter\ThreesixtyFormatter.
 */
 
namespace Drupal\field_slide_show_j360\Plugin\Field\FieldFormatter;
 
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\image\Plugin\Field\FieldFormatter\ImageFormatter;

/**
* Plugin implementation of the 'SlideShowJ360' formatter
*
* @FieldFormatter(
*   id = "SlideShowJ360",
*   label = @Translation("Slideshow j360"),
*   field_types = {
*     "image",
*   },
* )
*/
class ThreesixtyFormatter extends ImageFormatter {
  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return array(
      'height' => '265',
      'width' => '400',
      'navigation' => 'yes',
    ) + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $elements = parent::settingsForm($form, $form_state);
    $options = array('yes' => 'Display' , 'no' => 'Not Display');
    $elements['navigation'] = array(
      '#type' => 'select',
      '#title' => t('Navigation Display'),
      '#description' => t('Enable/Disable Navigation'),
      '#options' => $options,
      '#default_value' => $this->getSetting('navigation'),
    );
    $elements['width'] = array(
      '#type' => 'textfield',
      '#title' => t('Width'),
      '#description' => t('Select frame widht as youe theme required'),
      '#size' => 10,
      '#default_value' => $this->getSetting('width'),
      '#maxlength' => 4,
    );
    $elements['height'] = array(
      '#type' => 'textfield',
      '#title' => t('Height'),
      '#description' => t('Select frame height as your theme required'),
      '#size' => 10,
      '#default_value' => $this->getSetting('height'),
      '#maxlength' => 4,
    );
    
    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = array();

    $navigation = $this->getSetting('navigation');
    $width = $this->getSetting('width');
    $height = $this->getSetting('height');

    $summary[] = t('Slideshow j360 options:');
    $summary[] = t('Height: @height', array('@height' => $height));
    $summary[] = t('Width: @width', array('@width' => $width));
    $summary[] = t('Navigation: @navigation', array('@navigation' => $navigation));

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = array();
    $files = $this->getEntitiesToView($items, $langcode);

    $settings = $this->getSettings();
    $data = array();
    foreach ($files as $delta => $file) {
      $image_uri = $file->getFileUri();
      // @todo remove when min D9.2, and make file_create_url a service at 3.x.
      $dep = 'file_create_url';
      if(is_callable($dep)){
        $url = Url::fromUri($dep($image_uri));
      }else{
        $url = \Drupal::service('file_url_generator')->generateAbsoluteString($image_uri);
      }
      $data[] =  $url;
    }
    $elements['#attached']['library'][] = 'field_slide_show_j360/drupal_threesixty_slider';
    $elements['#attached']['library'][] = 'field_slide_show_j360/drupal.threeSixty';

    $elements[0] = array(
      '#theme' => 'slideShow360',
      '#image' => $data,
      '#settings' => $settings,
    );

    return $elements;
  }
}
